@@ -360,7 +360,7 @@ def GetUserManageableCollectionsInfo(user_url: str) -> list:
     return result
 
 def GetUserArticlesInfo(user_url: str, page: int = 1, count: int = 10, 
-                        sorting_method: str ="time") -> list:
+                        sorting_method: str = "time") -> list:
     """该函数接收用户个人主页 Url，并返回该链接对应用户的文章信息
 
     Args:
@@ -539,4 +539,70 @@ def GetUserAllBasicData(user_url: str) -> dict:
         result["introduction_text"] = "\n".join(etree.HTML(result["introduction_html"]).xpath("//*/text()"))
     result["next_anniversary_day"] = anniversary_day_html_obj.xpath('//*[@id="app"]/div[1]/div/text()')[0]
     result["next_anniversary_day"] = datetime.fromisoformat("-".join(findall(r"\d+", result["next_anniversary_day"])))
-    return result
\ No newline at end of file
+    return result
+
+def GetUserAllArticlesInfo(user_url: str, count: int = 10, sorting_method: str = "time") -> list:
+    """获取用户的所有文章信息
+
+    Args:
+        user_url (str): 用户个人主页 Url
+        count (int, optional): 单次获取的数据数量，会影响性能. Defaults to 10.
+        sorting_method (str, optional): 排序方法，time 为按照发布时间排序，
+        comment_time 为按照最近评论时间排序，hot 为按照热度排序. Defaults to "time".
+
+    Returns:
+        list: 用户的所有文章信息
+
+    Yields:
+        Iterator[list]: 当前页文章信息
+    """
+    page = 1
+    while True:
+        result = GetUserArticlesInfo(user_url, page, count, sorting_method)
+        if result:
+            yield result
+            page += 1
+        else:
+            break
+
+def GetUserAllFollowingInfo(user_url: str) -> list:
+    """获取用户的所有关注者信息
+
+    Args:
+        user_url (str): 用户个人主页 Url
+
+    Returns:
+        list: 用户的所有关注者信息
+
+    Yields:
+        Iterator[list]: 当前页关注者信息
+    """
+    page = 1
+    while True:
+        result = GetUserFollowingInfo(user_url, page)
+        if result:
+            yield result
+            page += 1
+        else:
+            break
+
+def GetUserAllFansInfo(user_url: str) -> list:
+    """获取用户的所有粉丝信息
+
+    Args:
+        user_url (str): 用户个人主页 Url
+
+    Returns:
+        list: 用户的所有粉丝信息
+
+    Yields:
+        Iterator[list]: 当前页粉丝信息
+    """
+    page = 1
+    while True:
+        result = GetUserFansInfo(user_url, page)
+        if result:
+            yield result
+            page += 1
+        else:
+            break
\ No newline at end of file
